@@ -6,12 +6,19 @@
 # as part of this package.
 
 
-__version__      = "0.01"
-__date__         = "2013-08-02"
+__version__      = "0.06"
+__date__         = "2014-06-17"
 __author__       = "Björn Johansson"
-__copyright__    = "Copyright 2013, Björn Johansson"
+__copyright__    = "Copyright 2013,2014, Björn Johansson"
 __credits__      = ["Björn Johansson"]
 __license__      = "BSD"
 __maintainer__   = "Björn Johansson"
 __email__        = "bjorn_johansson@bio.uminho.pt"
-__status__       = "Development" # "Production" #"Prototype"
\ No newline at end of file
+__status__       = "Development" # "Production" #"Prototype"
+
+from saccharomyces_cerevisiae import saccharomyces_cerevisiae_genome
+
+sg = saccharomyces_cerevisiae_genome()
+
+del saccharomyces_cerevisiae_genome
+
